<?php

namespace Drupal\mollie_commerce\EventSubscriber;

use Drupal\commerce_order\Entity\Order;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\HttpKernel\HttpKernelInterface;

/**
 * Base class for Mollie event subscribers.
 */
class MollieEventSubscriberBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The HTTP kernel.
   *
   * @var \Symfony\Component\HttpKernel\HttpKernelInterface
   */
  protected $httpKernel;

  /**
   * Constructs a new MollieEventSubscriberBase object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Symfony\Component\HttpKernel\HttpKernelInterface $http_kernel
   *   The HTTP kernel.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, HttpKernelInterface $http_kernel) {
    $this->entityTypeManager = $entity_type_manager;
    $this->httpKernel = $http_kernel;
  }

  /**
   * Returns the payment gateway ID for a Commerce order.
   *
   * @param string $order_id
   *   The Commerce order ID.
   *
   * @return string|null
   *   The ID of the payment gateway, or NULL if not found.
   */
  protected function getCommercePaymentGatewayIdByOrderId(string $order_id): ?string {
    $order = $this->getCommerceOrder($order_id);
    return $order?->get('payment_gateway')->target_id;
  }

  /**
   * Returns a Commerce order by ID.
   *
   * @param string $order_id
   *   The Commerce order ID.
   *
   * @return \Drupal\commerce_order\Entity\Order|null
   *   The Commerce order, or NULL if not found.
   */
  protected function getCommerceOrder(string $order_id): ?Order {
    /** @var \Drupal\commerce_order\Entity\Order $order */
    $order =  $this->entityTypeManager->getStorage('commerce_order')
      ->load($order_id);
    return $order;
  }

}
