<?php

namespace Drupal\mollie_commerce\PluginForm\OffsiteRedirect;

use Drupal\commerce\Response\NeedsRedirectException;
use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\Exception\MissingDataException;
use Drupal\mollie\Entity\Payment;
use Drupal\mollie\Mollie;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an offsite redirect form for Mollie payments.
 */
class MolliePaymentOffsiteForm extends PaymentOffsiteForm implements ContainerInjectionInterface {

  /**
   * The Mollie service.
   *
   * @var \Drupal\mollie\Mollie
   */
  protected $mollie;

  /**
   * Constructs a new MolliePaymentOffsiteForm object.
   *
   * @param \Drupal\mollie\Mollie $mollie
   *   The Mollie service.
   */
  public function __construct(Mollie $mollie) {
    $this->mollie = $mollie;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('mollie.mollie')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);

    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;

    try {
      // Create the Mollie payment.
      $transaction = Payment::createFromPaymentData([
        'amount' => number_format($payment->getAmount()->getNumber(), 2, '.', ''),
        'currency' => $payment->getAmount()->getCurrencyCode(),
        'description' => $this->t('@store order @order_id', [
          '@store' => $payment->getOrder()->getStore()->label(),
          '@order_id' => $payment->getOrderId(),
        ]),
        'context' => 'mollie_commerce',
        'context_id' => $payment->getOrderId(),
      ]);
      $transaction->save();

      // Store the Commerce payment.
      $payment->setRemoteId($transaction->getTransactionId());
      $payment->save();

      // Redirect to Mollie.
      return $this->buildRedirectForm($form, $form_state, $transaction->getCheckoutUrl(), [], 'get');
    }
    catch (MissingDataException | EntityStorageException $e) {
      watchdog_exception('mollie_commerce', $e);
    }
    return [];
  }

}
