<?php

namespace Drupal\mollie\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\mollie\Events\MollieRedirectEvent;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Provides a controller for redirecting after payment.
 */
class RedirectController extends ControllerBase {

  /**
   * The event dispatcher.
   *
   * @var \Symfony\Component\EventDispatcher\EventDispatcherInterface
   */
  protected $eventDispatcher;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = new static();
    $instance->eventDispatcher = $container->get('event_dispatcher');
    return $instance;
  }

  /**
   * Redirects the visitor to the appropriate place after payment.
   *
   * @param string $context
   *   The type of context that requested the payment.
   * @param string $context_id
   *   The ID of the context that requested the payment.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Response that redirects to the appropriate place.
   */
  public function paymentRedirect(string $context, string $context_id): RedirectResponse {
    // Redirect to the payment collection by default.
    $url = Url::fromRoute('entity.mollie_payment.collection');

    // Allow other modules to alter the redirect URL.
    $event = new MollieRedirectEvent($context, $context_id);
    $event->setRedirectUrl($url);
    $this->eventDispatcher->dispatch($event, MollieRedirectEvent::EVENT_NAME);

    return new RedirectResponse($event->getRedirectUrl()->toString());
  }

}
