<?php

namespace Drupal\mollie\EventSubscriber;

use Drupal\Core\Entity\EntityStorageException;
use Drupal\mollie\Entity\Payment;
use Drupal\mollie\Events\MollieTransactionChargebackEvent;
use Drupal\mollie\Events\MollieTransactionRefundEvent;
use Drupal\mollie\Events\MollieTransactionStatusChangeEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Provides an event subscriber for Mollie transaction changes.
 */
class PaymentChangeSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      MollieTransactionStatusChangeEvent::EVENT_NAME => ['updateMolliePayment', 100],
      MollieTransactionRefundEvent::EVENT_NAME => ['updateMolliePayment', 100],
      MollieTransactionChargebackEvent::EVENT_NAME => ['updateMolliePayment', 100],
    ];
  }

  /**
   * Updates the local payment when a payment has changed on the side of Mollie.
   *
   * This keeps our local copy of the Mollie data up to date.
   *
   * @param \Drupal\mollie\Events\MollieTransactionStatusChangeEvent $event
   *   The event.
   */
  public function updateMolliePayment(MollieTransactionStatusChangeEvent $event): void {
    $transaction = $event->getTransaction();
    $mollie_payment = $event->getMolliePayment();
    $transaction->set('data', Payment::MolliePaymentToArray($mollie_payment));
    try {
      $transaction->save();
      // Update the transaction on the event so that other event subscribers can
      // use the updated transaction.
      $event->setTransaction($transaction);
    }
    catch (EntityStorageException $e) {
      watchdog_exception('mollie', $e);
      $event->setHttpStatusCode(500);
    }
  }

}
