<?php

namespace Drupal\mollie\Events;

use Drupal\mollie\TransactionInterface;
use Mollie\Api\Resources\Payment;

/**
 * Class MollieTransactionEventBase.
 *
 * @package Drupal\mollie\Events
 */
abstract class MollieTransactionEventBase extends MollieEventBase {

  /**
   * The Mollie transaction.
   *
   * @var \Drupal\mollie\TransactionInterface
   */
  protected $transaction;

  /**
   * The Mollie payment.
   *
   * @var \Mollie\Api\Resources\Payment
   */
  protected $molliePayment;

  /**
   * HTTP status code to return to Mollie.
   *
   * @var int
   */
  protected $httpStatusCode;

  /**
   * MollieTransactionEventBase constructor.
   *
   * @param string $context
   *   Context that initiated the Mollie transaction this event is triggered
   *   for.
   * @param string $context_id
   *   ID of entity within the context corresponding to the Mollie transaction.
   * @param \Drupal\mollie\TransactionInterface $transaction
   *   The transaction entity.
   * @param \Mollie\Api\Resources\PaymentCollection $mollie_payment
   *   The Mollie payment.
   */
  public function __construct(string $context, string $context_id, TransactionInterface $transaction, Payment $mollie_payment) {
    parent::__construct($context, $context_id);

    $this->transaction = $transaction;
    $this->molliePayment = $mollie_payment;
  }

  /**
   * Sets the transaction for which the event is occurring.
   *
   * @param \Drupal\mollie\TransactionInterface $transaction
   *   The transaction entity.
   */
  public function setTransaction(TransactionInterface $transaction): void {
    $this->transaction = $transaction;
  }

  /**
   * Returns the transaction for which the event is occurring.
   *
   * @return \Drupal\mollie\TransactionInterface
   *   The transaction entity.
   */
  public function getTransaction(): TransactionInterface {
    return $this->transaction;
  }

  /**
   * Returns the Mollie payment for which the event is occurring.
   *
   * @return \Mollie\Api\Resources\Payment
   *   The Mollie payment.
   */
  public function getMolliePayment(): Payment {
    return $this->molliePayment;
  }

  /**
   * Sets the HTTP status code.
   *
   * @param int $httpStatusCode
   *   HTTP status code to return to Mollie.
   */
  public function setHttpStatusCode(int $httpStatusCode): void {
    $this->httpStatusCode = $httpStatusCode;
  }

  /**
   * Returns the HTTP status code.
   *
   * @return int
   *   HTTP status code currently set to return to Mollie.
   */
  public function getHttpStatusCode(): int {
    return $this->httpStatusCode;
  }

}
