<?php

namespace Drupal\mollie\Plugin\Field\FieldFormatter;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Field\Annotation\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Url;

/**
 * Provides a field formatter for Mollie payment data.
 *
 * @FieldFormatter(
 *   id = "mollie_payment_data",
 *   label = @Translation("Mollie payment data"),
 *   field_types = {
 *     "map"
 *   }
 * )
 */
class MolliePaymentData extends FormatterBase {

  /**
   * @inheritDoc
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];

    foreach ($items as $delta => $item) {
      $data = $item->getValue();
      $element[$delta][] = [
        '#type' => 'inline_template',
        // @todo Allow modules to alter the template and context.
        '#template' => '<div>{{ description }} / {{ amount }} {{ currency }}</div>',
        '#context' => [
          'description' => $data['description'],
          'amount' => number_format($data['amount']->value, 2),
          'currency' => $data['amount']->currency,
        ]
      ];
      if ($data['status'] === 'open') {
        $element[$delta][] = [
          '#type' => 'dropbutton',
          '#dropbutton_type' => 'small',
          '#links' => [
            'pay' => [
              'title' => $this->t('Pay'),
              'url' => Url::fromUri($data['checkoutUrl']),
            ],
          ]
        ];
      }
    }

    return $element;
  }

}
